function init(hero) {
    hero.setName("Jeweled Spider");
    hero.setTier(7);

    hero.setHelmet("item.superhero_armor.piece.mask");
    hero.setChestplate("item.superhero_armor.piece.chestpiece");
    hero.setLeggings("item.superhero_armor.piece.pants");
    hero.setBoots("item.superhero_armor.piece.boots");

    hero.addPowers("fiskheroes:spider_physiology", "smp:web_shooters", "smp:jeweled_symbiote");
    hero.addAttribute("FALL_RESISTANCE", 13.0, 0);
    hero.addAttribute("JUMP_HEIGHT", 2.5, 0);
    hero.addAttribute("PUNCH_DAMAGE", 7.5, 0);
    hero.addAttribute("SPRINT_SPEED", 0.5, 1);
    hero.addAttribute("STEP_HEIGHT", 0.5, 0);
    hero.addAttribute("IMPACT_DAMAGE", 0.5, 1);

    hero.addKeyBind("UTILITY_BELT", "key.webShooters", 1);
    hero.addKeyBind("WEB_ZIP", "key.webZip", 2);
    hero.addKeyBindFunc("func_WEB_SWINGING", webSwingingKey, "key.webSwinging", 3);
    hero.addKeyBind("SLOW_MOTION", "key.slowMotionHold", 4);
    hero.addKeyBind("BLADE", "key.blade", 4);
    hero.addKeyBind("SYMBIOTE_TRANSFORM", "Symbiotic Transformation", 5);

    hero.addKeyBind("TENTACLE_JAB", "key.tentacleJab", 1);
    hero.addKeyBind("TENTACLE_GRAB", "key.tentacleGrab", 2);
    hero.addKeyBind("TENTACLES", "key.tentacles", 5);

    hero.setModifierEnabled(isModifierEnabled);
    hero.setKeyBindEnabled(isKeyBindEnabled);

    hero.addAttributeProfile("SYMBIOTE", symbioteProfile);
    hero.addAttributeProfile("BLADE", bladeProfile);
    hero.setAttributeProfile(getProfile);
    hero.setDamageProfile(getProfile);
    hero.addDamageProfile("BLADE", {
        "types": {
            "SHARP": 1.0
        }
    });
}

function webSwingingKey(player, manager) {
    var flag = player.getData("fiskheroes:web_swinging");

    if (!flag) {
        manager.setDataWithNotify(player, "fiskheroes:prev_utility_belt_type", player.getData("fiskheroes:utility_belt_type"));
        manager.setDataWithNotify(player, "fiskheroes:utility_belt_type", -1);
    }

    manager.setDataWithNotify(player, "fiskheroes:tentacles", null);
    manager.setDataWithNotify(player, "fiskheroes:web_swinging", !flag);
    return true;
}

function isModifierEnabled(entity, modifier) {
    switch (modifier.name()) {
    case "fiskheroes:web_swinging":
        return entity.getHeldItem().isEmpty() && entity.getData("fiskheroes:utility_belt_type") == -1;
    case "fiskheroes:leaping":
        return modifier.id() == "springboard" == (entity.getData("fiskheroes:ticks_since_swinging") < 5);
    case "fiskheroes:blade":
        return entity.getData("fiskheroes:dyn/nanite_timer") == 1;
    case "fiskheroes:tentacles":
        return entity.getData("fiskheroes:dyn/nanite_timer") == 1 && !entity.getData("fiskheroes:web_swinging");
    default:
        return true;
    }
}

function isKeyBindEnabled(entity, keyBind) {
    switch (keyBind) {
    case "UTILITY_BELT":
        return entity.getData("fiskheroes:tentacles") == null;
    case "WEB_ZIP":
        return entity.getData("fiskheroes:tentacles") == null;
    case "func_WEB_SWINGING":
        return entity.getHeldItem().isEmpty();
    case "SLOW_MOTION":
        return entity.getData("fiskheroes:dyn/nanite_timer") ? !entity.isSneaking() : true;
    case "BLADE":
        return entity.getData("fiskheroes:dyn/nanite_timer") ? entity.isSneaking() : false;
    case "SYMBIOTE_TRANSFORM":
        return entity.getData("fiskheroes:dyn/nanites") ? entity.isSneaking() : true;
    case "TENTACLE_JAB":
        return entity.getData("fiskheroes:tentacles") != null;
    case "TENTACLES_GRAB":
        return entity.getData("fiskheroes:tentacles") != null;
    case "TENTACLES":
        return entity.getData("fiskheroes:dyn/nanite_timer") == 1 && !entity.isSneaking();
    default:
        return true;
    }
}

function getTierOverride(entity) {
    return entity.getData("fiskheroes:dyn/nanites") ? 8 : 7;
}

function symbioteProfile(profile) {
    profile.inheritDefaults();
    profile.addAttribute("FALL_RESISTANCE", 16.0, 0);
    profile.addAttribute("JUMP_HEIGHT", 3.0, 0);
    profile.addAttribute("PUNCH_DAMAGE", 9.0, 0);
    profile.addAttribute("SPRINT_SPEED", 0.6, 1);
    profile.addAttribute("IMPACT_DAMAGE", 0.6, 1);
}

function bladeProfile(profile) {
    profile.inheritDefaults();
    profile.addAttribute("FALL_RESISTANCE", 16.0, 0);
    profile.addAttribute("JUMP_HEIGHT", 3.0, 0);
    profile.addAttribute("PUNCH_DAMAGE", 11.5, 0);
    profile.addAttribute("SPRINT_SPEED", 0.6, 1);
    profile.addAttribute("IMPACT_DAMAGE", 0.6, 1);
}

function getProfile(entity) {
    return entity.getData("fiskheroes:blade") ? "BLADE" : entity.getData("fiskheroes:dyn/nanites") ? "SYMBIOTE" : null;
}